Class: BlackStack::Infrastructure::Node

Inherits:
Object
  • Object
show all
Includes:
NodeModule
Defined in:
lib/blackstack-nodes.rb

Overview

TODO: declare these classes (stub and skeleton) using blackstack-rpc

Node Stub This class represents a node, without using connection to the database. Use this class at the client side.

Instance Attribute Summary collapse

Attributes included from NodeModule

#logger, #ssh

Method Summary

Methods included from NodeModule

#connect, descriptor_errors, #disconnect, #exec, #initialize, #reboot, #to_hash, #using_password?, #using_private_key_file?

Instance Attribute Details

#name ⇒ Object

:name is this is just a descriptive name for the node. It is not the host name, nor the domain, nor any ip.



153
154
155
# File 'lib/blackstack-nodes.rb', line 153

def name
  @name
end

#net_remote_ip ⇒ Object

:name is this is just a descriptive name for the node. It is not the host name, nor the domain, nor any ip.



153
154
155
# File 'lib/blackstack-nodes.rb', line 153

def net_remote_ip
  @net_remote_ip
end

#ssh_password ⇒ Object

:name is this is just a descriptive name for the node. It is not the host name, nor the domain, nor any ip.



153
154
155
# File 'lib/blackstack-nodes.rb', line 153

def ssh_password
  @ssh_password
end

#ssh_port ⇒ Object

:name is this is just a descriptive name for the node. It is not the host name, nor the domain, nor any ip.



153
154
155
# File 'lib/blackstack-nodes.rb', line 153

def ssh_port
  @ssh_port
end

#ssh_private_key_file ⇒ Object

:name is this is just a descriptive name for the node. It is not the host name, nor the domain, nor any ip.



153
154
155
# File 'lib/blackstack-nodes.rb', line 153

def ssh_private_key_file
  @ssh_private_key_file
end

#ssh_username ⇒ Object

:name is this is just a descriptive name for the node. It is not the host name, nor the domain, nor any ip.



153
154
155
# File 'lib/blackstack-nodes.rb', line 153

def ssh_username
  @ssh_username
end